@@ -14,6 +14,11 @@ class Api(object):
         """
         raise NotImplementedError
 
+    def set_flow_transmit(self, content):
+        """TBD
+        """
+        raise NotImplementedError
+
     def get_capability_results(self, content):
         """TBD
         """
@@ -23,3 +28,8 @@ class Api(object):
         """TBD
         """
         raise NotImplementedError
+
+    def get_flow_results(self, content):
+        """TBD
+        """
+        raise NotImplementedError
