@@ -10,13 +10,12 @@ def test_default_port(serializer):
     assert(port.location is None)
 
 def test_physical_port(serializer):
-    name = "Physical Port"
-    physical = Physical(address='127.0.0.1', board=1, port=1)
-    port = Port(name=name, location=Location(physical))
+    name = 'Physical Port'
+    location = '127.0.0.1;1;1'
+    port = Port(name=name, location=location)
     print(serializer.json(port))
     assert(port.name == name)
-    assert(port.location.choice == 'physical')
-    assert(port.location.physical.address == '127.0.0.1')
+    assert(port.location == location)
 
 
 if __name__ == '__main__':
